<?php
/*
  Plugin Name: Beek Widget Extention
  Plugin URI: http://beek.jp/beek-widget-extention/
  Description: Will extend the widget of WordPress. And add some shortcode.
  Version: 0.9.5
  Author: Satoshi Yoshida
  Author URI: http://beek.jp
  License: GPLv2 or later
 */
/*  Copyright 2015 Satoshi Yoshida (email : yos.3104@gmail.com)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

require_once dirname(__FILE__) . '/inc/bwe-hook.php';
require_once dirname(__FILE__) . '/inc/heading.php';
require_once dirname(__FILE__) . '/inc/menu.php';
require_once dirname(__FILE__) . '/inc/image.php';
require_once dirname(__FILE__) . '/inc/cover.php';
require_once dirname(__FILE__) . '/inc/call-to-action.php';
require_once dirname(__FILE__) . '/inc/custom-post-category.php';
require_once dirname(__FILE__) . '/inc/custom-post-list.php';
require_once dirname(__FILE__) . '/inc/custom-post-archive.php';

class BeekSettings {

	function __construct() {
		add_action('admin_menu', array($this, 'add_pages'));
	}

	function add_pages() {
		add_submenu_page('plugins.php', __('BWE Settings', 'beek-widget-extention'), __('BWE Settings', 'beek-widget-extention'), 'level_8', __FILE__, array($this, 'setting_view'));
	}

	function setting_view() {
		$post_settings = filter_input(INPUT_POST, "beek_widget_settings", FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
		if (!is_null($post_settings)) {
			check_admin_referer('beek_widget_settings');
			update_option('beek_widget_settings', $post_settings);
			?><div class="updated fade"><p><strong><?php _e('Settings saved.', 'beek-widget-extention'); ?></strong></p></div><?php
		}
		?>
		<div class="bwe-admin-settings-wrapper">
			<h1><?php _e('Beek Widget Extention Settings', 'beek-widget-extention'); ?></h1>
			<form action="" method="post">
				<?php
				wp_nonce_field('beek_widget_settings');
				$settings = get_option('beek_widget_settings');
				$base_font_size = isset($settings['base_font_size']) ? esc_html($settings['base_font_size']) : 14;
				$no_image = ($settings['no_image']) ? esc_html($settings['no_image']) : plugins_url('images/bwe-no-thumbnail.png', __FILE__);
				?>
				<h2><?php _e('Base font size', 'beek-widget-extention'); ?></h2>
				<input name="beek_widget_settings[base_font_size]" min="10" max="64" type="number" value="<?php echo $base_font_size; ?>">px

				<h2><?php _e('Default thumbnail', 'beek-widget-extention'); ?></h2>
				<div class="image-selector">
					<?php
					$bwe_access_key = bwe_get_rand_str(16);
					?>
					<span class="bwe-image-preview" style="display: <?php ($no_image) ? print 'block' : print 'none'; ?>;">
						<img class="bwe-selected-image <?php echo $bwe_access_key; ?>" src="<?php echo $no_image; ?>" alt="">
					</span>
					<input class="image-url <?php echo $bwe_access_key; ?>"
						   name="beek_widget_settings[no_image]"
						   type="text"
						   value="<?php echo $no_image; ?>" />
					<a class="select-image" data-target="<?php echo $bwe_access_key; ?>">Select</a>
					<a class="clear-image" data-target="<?php echo $bwe_access_key; ?>">Clear</a>
				</div>

				<p class="submit"><input type="submit" name="Submit" class="button-primary" value="<?php _e('Save', 'beek-widget-extention'); ?>"></p>
			</form>
			<h1><?php _e('Extra', 'beek-widget-extention'); ?></h1>
			<article class="bwe-shortcode-list">
				<h2><?php _e('Beek Widget Extention shortcode format and options', 'beek-widget-extention'); ?></h2>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Call to Action Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_cta option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>text</td><td>text</td><td></td></tr>
								<tr><td>url</td><td>url</td><td></td></tr>
								<tr><td>reverse</td><td>normal<br>reverse</td><td>normal</td></tr>
								<tr><td>color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>black</td></tr>
								<tr><td>width</td><td>100<br>90<br>80<br>70<br>60<br>50<br>40</td><td>70</td></tr>
								<tr><td>size</td><td>extra-small<br>small<br>middle<br>large<br>extra-large</td><td>middle</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Heading Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_heading option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>heading</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>text_align</td><td>left<br>center<br>right</td><td>center</td></tr>
								<tr><td>title</td><td>text</td><td></td></tr>
								<tr><td>title_bold</td><td>normal<br>bold<br>lighter<br>bolder<br>100<br>200<br>300<br>400<br>500<br>600<br>700<br>800<br>900</td><td>normal</td></tr>
								<tr><td>text</td><td>text</td><td></td></tr>
								<tr><td>border_color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>black</td></tr>
								<tr><td>border_width</td><td>0～20</td><td>2</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Image Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_image option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>image</td><td>image url</td><td></td></tr>
								<tr><td>overlay</td><td>none<br>overlay<br>reverse-overlay</td><td>none</td></tr>
								<tr><td>overlay_color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>white</td></tr>
								<tr><td>alt</td><td>text</td><td></td></tr>
								<tr><td>url</td><td>url</td><td></td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Cover Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_cover option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>image</td><td>image url</td><td></td></tr>
								<tr><td>cover_color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>none</td></tr>
								<tr><td>cover_position</td><td>full-width<br>half-left<br>half-right</td><td>full-width</td></tr>
								<tr><td>title_type</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>title</td><td>text</td><td></td></tr>
								<tr><td>text</td><td>text</td><td></td></tr>
								<tr><td>text_color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>white</td></tr>
								<tr><td>url_text</td><td>text</td><td></td></tr>
								<tr><td>url</td><td>url</td><td></td></tr>
								<tr><td>url_color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>white</td></tr>
								<tr><td>url_type</td><td>anchor<br>button</td><td>anchor</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Menu Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_menu option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>title</td><td>title text</td><td></td></tr>
								<tr><td>title_size</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>menu_name</td><td>menu name</td><td></td></tr>
								<tr><td>output</td><td>plain-ul<br>decoration-ul<br>header-menu<br>parent-grid-1<br>parent-grid-2<br>parent-grid-3<br>parent-grid-4</td><td>plain-ul</td></tr>
								<tr><td>color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>black</td></tr>
								<tr><td>font_size</td><td>extra-small<br>small<br>medium<br>large<br>extra-large</td><td>medium</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Custom Post Category Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_cp_category option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>title</td><td>title text</td><td></td></tr>
								<tr><td>title_size</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>taxonomy</td><td>taxonomy slug</td><td>category</td></tr>
								<tr><td>count</td><td>show<br>hide</td><td>show</td></tr>
								<tr><td>smallest</td><td>0.6<br>0.7<br>0.8<br>0.9<br>1.0<br>1.1<br>1.2</td><td>0.8</td></tr>
								<tr><td>largest</td><td>1.2<br>1.3<br>1.4<br>1.5<br>1.6<br>1.7<br>1.8<br>1.9<br>2.0</td><td>1.8</td></tr>
								<tr><td>output</td><td>plain-ul<br>plain-tag-cloud<br>decoration-ul<br>decoration-tag-cloud</td><td>plain-ul</td></tr>
								<tr><td>color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>black</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Custom Post Archive Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_cp_archive option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>title</td><td>title text</td><td></td></tr>
								<tr><td>title_size</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>post_type</td><td>post type slug</td><td>post</td></tr>
								<tr><td>output</td><td>plain-ul<br>decoration-ul</td><td>plain-ul</td></tr>
								<tr><td>color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>black</td></tr>
							</tbody>
						</table>
					</div>
				</section>
				<section class="bwe-shortcode">
					<h3 class="bwe-shortcode-title">&rarr;<?php _e('Beek Custom Post List Widget', 'beek-widget-extention'); ?></h3>
					<div class="bwe-shortcode-detail">
						<p><?php _e('Shortcode format:', 'beek-widget-extention'); ?><input type="text" class="bwe-shortcode-template" value='[bwe_cp_list option="value" /]' onclick="this.select();"></p>
						<table class="bwe-shortcode-options">
							<thead>
								<tr><th><?php _e('Option', 'beek-widget-extention'); ?></th><th><?php _e('Configurable', 'beek-widget-extention'); ?></th><th><?php _e('Default', 'beek-widget-extention'); ?></th></tr>
							</thead>
							<tbody>
								<tr><td>title</td><td>title text</td><td></td></tr>
								<tr><td>title_size</td><td>h1<br>h2<br>h3<br>h4<br>h5</td><td>h3</td></tr>
								<tr><td>post_type</td><td>post type slug</td><td>post</td></tr>
								<tr><td>taxonomy_slug</td><td>taxonomy slug</td><td>category</td></tr>
								<tr><td>order</td><td>DESC<br>ASC</td><td>DESC</td></tr>
								<tr><td>order_by</td><td>none<br>ID<br>author<br>title<br>date<br>modified<br>comment_count</td><td>date</td></tr>
								<tr><td>output</td><td>plain-ul<br>plain-posts<br>plain-grid-1<br>plain-grid-2<br>plain-grid-3<br>plain-grid-4<br>decoration-ul<br>decoration-posts<br>decoration-grid-1<br>decoration-grid-2<br>decoration-grid-3<br>decoration-grid-4</td><td>plain-posts</td></tr>
								<tr><td>count</td><td>1～20</td><td>10</td></tr>
								<tr><td>overlay</td><td>none<br>overlay<br>reverse-overlay</td><td>none</td></tr>
								<tr><td>color</td><td>black<br>red<br>pink<br>purple<br>indigo<br>blue<br>green<br>orange</td><td>white</td></tr>
								<tr><td>pagination</td><td>show<br>hide<br>ajax-load<br>ajax-auto-load</td><td>show</td></tr>
							</tbody>
						</table>
					</div>
				</section>
			</article>
			<h2><?php _e('Support', 'beek-widget-extention'); ?></h2>
			<p>
				<?php _e('Please contact me if you need help.', 'beek-widget-extention'); ?><br>
				<?php _e('Mail:<a href="mailto:yos.3104@gmail.com">yos.3104@gmail.com</a>', 'beek-widget-extention'); ?><br>
				<?php _e('Twitter:<a href="https://twitter.com/beek_jp" target="_blank">@beek_jp</a>', 'beek-widget-extention'); ?><br>
			</p>
		</div>
		<?php
	}

	function get_base_font_size() {
		$option = get_option('beek_widget_settings');
		return isset($option['base_font_size']) ? $option['base_font_size'] : 14;
	}

	function get_no_image() {
		$option = get_option('beek_widget_settings');
		return ($option['no_image']) ? $option['no_image'] : plugins_url('images/bwe-no-thumbnail.png', __FILE__);
	}

}

$beek_settings = new BeekSettings();


/* Load scripts and styles */
add_action('wp_enqueue_scripts', 'beek_enqueue_files');
add_action( 'admin_enqueue_scripts', 'beek_load_media' );
add_action('admin_menu', 'beek_admin_enqueue_files');

function beek_load_media() {
	wp_enqueue_media();
}

function beek_admin_enqueue_files() {
	wp_register_style('beek-widget-extention-style-admin', plugins_url('', __FILE__) . '/css/beek-widget-extention-admin.css', array(), '0.1.0');
	wp_register_script('beek-widget-extention-sctipt-admin', plugins_url('', __FILE__) . '/js/beek-widget-extention-admin.js', array("jquery"), '0.1.0', TRUE);
	wp_enqueue_style('beek-widget-extention-style-admin');
	wp_enqueue_script('beek-widget-extention-sctipt-admin');
}

function beek_enqueue_files() {
	wp_register_style('responsive-gs', plugins_url('', __FILE__) . '/component/responsive.gs/responsive.gs.12col.css', array(), '3.0');
	wp_register_style('beek-widget-extention-style', plugins_url('', __FILE__) . '/css/beek-widget-extention.css', array(), '0.1.1');
	wp_register_script('beek-widget-extention-sctipt', plugins_url('', __FILE__) . '/js/beek-widget-extention.js', array("jquery"), '0.2.1', TRUE);
	wp_enqueue_script('jquery');
	wp_enqueue_style('responsive-gs');
	wp_enqueue_style('beek-widget-extention-style');
	wp_enqueue_script('beek-widget-extention-sctipt');
}

add_action('widgets_init', function() {
	register_widget('BeekHeading');
	register_widget('BeekMenu');
	register_widget('BeekImage');
	register_widget('BeekCover');
	register_widget('BeekCallToAction');
	register_widget('BeekCustomPostCategory');
	register_widget('BeekCustomPostList');
	register_widget('BeekCustomPostArchive');
});




/* Beek Widget Extention Plugin Load */

function bwe_load_plugin() {
	load_plugin_textdomain('beek-widget-extention', FALSE, basename(dirname(__FILE__)) . '/languages');
}

add_action('plugins_loaded', 'bwe_load_plugin');


/* random string */

function bwe_get_rand_str($length) {
	static $chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJLKMNOPQRSTUVWXYZ0123456789';
	$str = '';
	for ($i = 0; $i < $length; ++$i) {
		$str .= $chars[mt_rand(0, 61)];
	}
	return $str;
}
